# django-summernote-ajax
[![Build Status](https://travis-ci.org/summernote/django-summernote-ajax.svg?branch=master)](https://travis-ci.org/summernote/django-summernote-ajax)
[![Coverage Status](https://coveralls.io/repos/github/summernote/django-summernote-ajax/badge.svg?branch=master)](https://coveralls.io/github/summernote/django-summernote-ajax?branch=master)

Summernote & Ajax Image Upload on Django

**CURRENTLY UNDER DEVELOPMENT**

This package is not off-the-shelf product.

If you look for django extension for summernote with out of the functionality, we recommend to use [django-summernote](https://github.com/summernote/django-summernote).

# Installation and Setup
## Install package
```
pip install django-summernote-ajax
```

## Register into installed apps
```
INSTALLED_APPS += [
    ...
    'django_summernote_ajax',
    ...
]
```

# Features

# Dependencies
for library
* Django>=1.11 (1.8 LTs is supported until April 2018.)
* pytz==2017.3
* jQuery==3.3.1
* Bootstrap==4.0.0
* Summernote=0.8.9

for sandbox demo
* django-crispy-forms==1.7.0
* Pillow==5.0.0
* celery==4.1.0

# License
MIT
